@@ -3,7 +3,7 @@
 
 #include <QDialog>
 
-class ClassicPrint;
+class MainWindow;
 
 namespace Ui {
     class SettingsDialog;
@@ -14,7 +14,7 @@ class SettingsDialog : public QDialog
     Q_OBJECT
 
 public:
-	explicit SettingsDialog(ClassicPrint* print, QWidget *parent = 0);
+	explicit SettingsDialog(MainWindow* main_wnd, QWidget *parent = 0);
     ~SettingsDialog();
 
 protected:
@@ -26,7 +26,7 @@ private:
 
 private:
     Ui::SettingsDialog *ui;
-	ClassicPrint*		m_print;
+	MainWindow*			m_main_wnd;
 	QString				m_negatives_folder;
 	QString				m_developed_folder;
 
