@@ -54,9 +54,6 @@ ClassicPrint::ClassicPrint() {
     m_current_processing = NULL;
 	m_save_width = 0;
 	m_save_height = 0;
-	m_camera_mp = 5;
-	m_keep_negatives = true;
-	m_process_preview = true;
 
 	m_cancel = false;
 
@@ -89,6 +86,7 @@ bool ClassicPrint::init() {
 	REGISTER_CONTRAST_FILTER;
 	REGISTER_COLOUR_LOOKUP_FILTER;
 	REGISTER_BLEND_FILTER;
+	return true;
 }
 
 //---------------------------------------------------------------------------
@@ -192,28 +190,6 @@ bool ClassicPrint::save(QString filename, bool current_settings_only) {
 			save_height.appendChild(save_text);
 			root.appendChild(save_height);
 		}
-		if (m_negatives_folder.size() > 0) {
-			QDomElement	neg_dir = doc.createElement("NegativesFolder");
-			QDomText	neg_text = doc.createTextNode(m_negatives_folder);
-			neg_dir.appendChild(neg_text);
-			root.appendChild(neg_dir);
-		}
-		if (m_developed_folder.size() > 0) {
-			QDomElement	dev_dir = doc.createElement("DevelopedFolder");
-			QDomText	dev_text = doc.createTextNode(m_developed_folder);
-			dev_dir.appendChild(dev_text);
-			root.appendChild(dev_dir);
-		}
-		QDomElement	elem_keep = doc.createElement("KeepNegatives");
-		QDomText	text_keep = doc.createTextNode(m_keep_negatives ? "1" : "0");
-		elem_keep.appendChild(text_keep);
-		root.appendChild(elem_keep);
-
-		QDomElement	elem_prev = doc.createElement("ProcessPreview");
-		QDomText	text_prev = doc.createTextNode(m_process_preview ? "1" : "0");
-		elem_prev.appendChild(text_prev);
-		root.appendChild(elem_prev);
-
 		// Save the list of lenses
 		QDomElement    lenses = doc.createElement("Lenses");
 		root.appendChild(lenses);
@@ -244,11 +220,6 @@ bool ClassicPrint::save(QString filename, bool current_settings_only) {
 			itproc.value()->save_node(doc, process);
 		}
 	}
-	// Camera resolution forms part of the current settings
-	QDomElement	elem_mp = doc.createElement("CameraMp");
-	QDomText	text_mp = doc.createTextNode(QVariant(m_camera_mp).toString());
-	elem_mp.appendChild(text_mp);
-	root.appendChild(elem_mp);
 
 	// Save the current lens, process and film
     if (m_current_lens) {
@@ -321,21 +292,6 @@ bool ClassicPrint::load(QString filename) {
 			else if (e.tagName() == "LastSaveHeight") {
 				m_save_height = e.text().toInt();
 			}
-			else if (e.tagName() == "NegativesFolder") {
-				m_negatives_folder = e.text();
-			}
-			else if (e.tagName() == "DevelopedFolder") {
-				m_developed_folder = e.text();
-			}
-			else if (e.tagName() == "KeepNegatives") {
-				m_keep_negatives = e.text().toInt() ? true : false;
-			}
-			else if (e.tagName() == "ProcessPreview") {
-				m_process_preview = e.text().toInt() ? true : false;
-			}
-			else if (e.tagName() == "CameraMp") {
-				m_camera_mp = e.text().toInt();
-			}
 			else if (e.tagName() == "Lenses") {
                 QDomNode child = e.firstChild();
                 while (!child.isNull()) {
@@ -906,118 +862,6 @@ int ClassicPrint::saveHeight() {
 	return m_save_height;
 }
 
-//---------------------------------------------------------------------------
-/*!
-** @brief   Set the folder to save negatives in (classiccam setting)
-**
-** @param[in] folder	Folder to save negatives in
-*/
-void ClassicPrint::setNegativesFolder(const QString& folder) {
-	m_negatives_folder = folder;
-	// Make sure it has a slash on the end
-	if (m_negatives_folder.size() > 0) {
-		if (m_negatives_folder[m_negatives_folder.size()-1] != '/') {
-			m_negatives_folder += "/";
-		}
-	}
-}
-
-//---------------------------------------------------------------------------
-/*!
-** @brief   Get the folder to save negatives in (classiccam setting)
-**
-** @return	Folder to save negatives in
-*/
-const QString& ClassicPrint::negativesFolder() {
-	return m_negatives_folder;
-}
-
-//---------------------------------------------------------------------------
-/*!
-** @brief   Set the folder to save developed images in (classiccam setting)
-**
-** @param[in] folder	Folder to save developed images in
-*/
-void ClassicPrint::setDevelopedFolder(const QString& folder) {
-	m_developed_folder = folder;
-	// Make sure it has a slash on the end
-	if (m_developed_folder.size() > 0) {
-		if (m_developed_folder[m_developed_folder.size()-1] != '/') {
-			m_developed_folder += "/";
-		}
-	}
-}
-
-//---------------------------------------------------------------------------
-/*!
-** @brief   Get the folder to save developed images in (classiccam setting)
-**
-** @return	Folder to save developed images in
-*/
-const QString& ClassicPrint::developedFolder() {
-	return m_developed_folder;
-}
-
-//---------------------------------------------------------------------------
-/*!
-** @brief   Set the flag that indicates whether to keep or delete negatives
-**
-** @param[in] keep	True=keep, False = delete negatives when developed
-*/
-void ClassicPrint::setKeepNegatives(bool keep) {
-	m_keep_negatives = keep;
-}
-
-//---------------------------------------------------------------------------
-/*!
-** @brief   Get the flag that indicates whether to keep or delete negatives
-**
-** @return	True=keep, False = delete negatives when developed
-*/
-bool ClassicPrint::keepNegatives() {
-	return m_keep_negatives;
-}
-
-//---------------------------------------------------------------------------
-/*!
-** @brief   Set the flag that indicates whether to process the camera preview image
-**
-** @param[in] process	True=Process, False=No Process
-*/
-void ClassicPrint::setProcessPreview(bool process) {
-	m_process_preview = process;
-}
-
-//---------------------------------------------------------------------------
-/*!
-** @brief   Get the flag that indicates whether to process the camera preview image
-**
-** @return	True=Process, False=No Process
-*/
-bool ClassicPrint::processPreview() {
-	return m_process_preview;
-}
-
-//---------------------------------------------------------------------------
-/*!
-** @brief   Set the camera megapixels
-**
-** @param[out] mp		Resolution
-*/
-void ClassicPrint::setCameraMp(int mp) {
-	m_camera_mp = mp;
-}
-
-//---------------------------------------------------------------------------
-/*!
-** @brief   Get the camera megapixels
-**
-** @return	resolution
-*/
-int ClassicPrint::cameraMp() {
-	return m_camera_mp;
-}
-
 void ClassicPrint::on_cancel() {
 	printf("Cancelled\n");
 	m_cancel = true;
